@@ -1,8 +1,8 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2018 by Simon Depiets <sdepiets@gmail.com>
-                2007-2017 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2017 by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
