@@ -278,6 +278,8 @@ void EditorTab::setupActions()
     connect(m_view, &EditorView::signalChanged, m_notesView, &MsgCtxtView::removeErrorNotes);
     connect(m_notesView, &MsgCtxtView::escaped, this, &EditorTab::setProperFocus);
 
+    connect((const TranslationUnitTextEdit*)m_view->viewPort(), &TranslationUnitTextEdit::languageToolChanged, m_notesView, &MsgCtxtView::languageTool);
+
     action = edit->addAction(QStringLiteral("edit_addnote"), m_notesView, SLOT(addNoteUI()));
     //action->setShortcut(Qt::CTRL+glist[i]);
     action->setText(i18nc("@action:inmenu", "Add a note"));
@@ -541,6 +543,10 @@ void EditorTab::setupActions()
     ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_T));
     action->setText(i18nc("@action:inmenu", "Insert Tag"));
 
+    action = edit->addAction(QStringLiteral("edit_languagetool"), m_view->viewPort(), SLOT(launchLanguageTool()));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_J));
+    action->setText(i18nc("@action:inmenu", "Check this unit using LanguageTool"));
+
     action = edit->addAction(QStringLiteral("edit_tagimmediate"), m_view->viewPort(), SLOT(tagImmediate()));
     ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_M));
     action->setText(i18nc("@action:inmenu", "Insert Next Tag"));
@@ -802,7 +808,7 @@ void EditorTab::updateCaptionPath()
         _captionPath = _captionPath.mid(2);
 }
 
-bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, bool silent)
+bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QString, QMdiSubWindow*> openedFiles, bool silent)
 {
     if (!m_catalog->isClean()) {
         switch (KMessageBox::warningYesNoCancel(SettingsController::instance()->mainWindowPtr(),
@@ -839,6 +845,11 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, bool silent
     }
     if (filePath.isEmpty())
         return false;
+    QMap<QString, QMdiSubWindow*>::const_iterator it = openedFiles.constFind(filePath);
+    if (it != openedFiles.constEnd()) {
+        qCWarning(LOKALIZE_LOG) << "already opened:" << filePath;
+        return false;
+    }
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
