@@ -66,7 +66,7 @@ MsgCtxtView::MsgCtxtView(QWidget* parent, Catalog* catalog)
     m_stackedLayout = new QStackedLayout(main);
     m_stackedLayout->addWidget(m_browser);
 
-    m_browser->viewport()->setBackgroundRole(QPalette::Background);
+    m_browser->viewport()->setBackgroundRole(QPalette::Window);
     m_browser->setOpenLinks(false);
     connect(m_browser, &QTextBrowser::anchorClicked, this, &MsgCtxtView::anchorClicked);
 }
@@ -81,6 +81,8 @@ void MsgCtxtView::cleanup()
 {
     m_unfinishedNotes.clear();
     m_tempNotes.clear();
+    m_pologyNotes.clear();
+    m_languageToolNotes.clear();
 }
 
 void MsgCtxtView::gotoEntry(const DocPosition& pos, int selection)
@@ -119,6 +121,22 @@ void MsgCtxtView::process()
         html += MsgCtxtView::BR;
         m_browser->insertHtml(html.replace('\n', MsgCtxtView::BR));
     }
+    if (m_pologyNotes.contains(m_entry.entry)) {
+        QString html = i18nc("@info notes generated by the pology check", "<b>Pology notes:</b>");
+        html += MsgCtxtView::BR;
+        foreach (const QString& note, m_pologyNotes.values(m_entry.entry))
+            html += note.toHtmlEscaped() + MsgCtxtView::BR;
+        html += MsgCtxtView::BR;
+        m_browser->insertHtml(html.replace('\n', MsgCtxtView::BR));
+    }
+    if (m_languageToolNotes.contains(m_entry.entry)) {
+        QString html = i18nc("@info notes generated by the languagetool check", "<b>LanguageTool notes:</b>");
+        html += MsgCtxtView::BR;
+        foreach (const QString& note, m_languageToolNotes.values(m_entry.entry))
+            html += note.toHtmlEscaped() + MsgCtxtView::BR;
+        html += MsgCtxtView::BR;
+        m_browser->insertHtml(html.replace('\n', MsgCtxtView::BR));
+    }
 
     QString phaseName = m_catalog->phase(m_entry.toDocPosition());
     if (!phaseName.isEmpty()) {
@@ -166,6 +184,12 @@ void MsgCtxtView::process()
     t.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, m_selection);
     m_browser->setTextCursor(t);
 }
+void MsgCtxtView::languageTool(const QString &text)
+{
+    m_languageToolNotes.insert(m_entry.entry, text);
+    m_prevEntry.entry = -1;
+    process();
+}
 void MsgCtxtView::pology()
 {
     if (Settings::self()->pologyEnabled() && m_pologyProcessInProgress == 0 && QFile::exists(m_catalog->url())) {
@@ -181,7 +205,7 @@ void MsgCtxtView::pology()
                 this, &MsgCtxtView::pologyReceivedStandardError);
         connect(m_pologyProcess, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished),
                 this, &MsgCtxtView::pologyHasFinished);
-        m_pologyData = QStringLiteral("[pology] ");
+        m_pologyData = QStringLiteral("");
         m_pologyProcessInProgress = m_entry.entry + 1;
         m_pologyProcess->start();
     } else if (Settings::self()->pologyEnabled() && m_pologyProcessInProgress > 0) {
@@ -229,14 +253,9 @@ void MsgCtxtView::pologyHasFinished()
                 }
             }
         }
-        if (!m_tempNotes.value(m_entry.entry).startsWith(QStringLiteral("Failed rules:"))) {
-            //This was not opened by pology
-            //Delete the previous pology notes
-            if (m_tempNotes.value(m_entry.entry).startsWith(QStringLiteral("[pology] "))) {
-                m_tempNotes.remove(m_entry.entry);
-            }
-            addTemporaryEntryNote(m_entry.entry, m_pologyData);
-        }
+        m_pologyNotes.insert(m_entry.entry, m_pologyData);
+        m_prevEntry.entry = -1;
+        process();
     }
     m_pologyProcess->deleteLater();
     m_pologyProcessInProgress = 0;
@@ -311,7 +330,8 @@ void MsgCtxtView::addNote(DocPosition p, const QString& text)
 void MsgCtxtView::addTemporaryEntryNote(int entry, const QString& text)
 {
     m_tempNotes.insertMulti(entry, text);
-    m_prevEntry.entry = -1; process();
+    m_prevEntry.entry = -1;
+    process();
 }
 
 void MsgCtxtView::removeErrorNotes()
@@ -326,7 +346,8 @@ void MsgCtxtView::removeErrorNotes()
             m_catalog->push(new SetNoteCmd(m_catalog, p, Note()));
     }
 
-    m_prevEntry.entry = -1; process();
+    m_prevEntry.entry = -1;
+    process();
 }
 
 
