@@ -51,7 +51,7 @@ public:
 public slots:
     void removeErrorNotes();
     void cleanup();
-
+    void languageTool(const QString& text);
     void addNoteUI();
 private slots:
     void anchorClicked(const QUrl& link);
@@ -75,6 +75,8 @@ private:
     Catalog* m_catalog;
     QMap< DocPos, QPair<Note, int> > m_unfinishedNotes; //note and its index
     QMap< int, QString > m_tempNotes;
+    QMap< int, QString > m_pologyNotes;
+    QMap< int, QString > m_languageToolNotes;
     int  m_selection;
     int  m_offset;
     bool m_hasInfo;
