@@ -253,7 +253,7 @@ PhasesWindow::PhasesWindow(Catalog* catalog, QWidget *parent)
     m_stackedLayout = new QStackedLayout(m_noteView);
     m_stackedLayout->addWidget(m_browser);
 
-    m_browser->viewport()->setBackgroundRole(QPalette::Background);
+    m_browser->viewport()->setBackgroundRole(QPalette::Window);
     m_browser->setOpenLinks(false);
     connect(m_browser, &QTextBrowser::anchorClicked, this, &PhasesWindow::anchorClicked);
 
