@@ -149,7 +149,7 @@ TMView::TMView(QWidget* parent, Catalog* catalog, const QVector<QAction*>& actio
     setWidget(m_browser);
 
     m_browser->document()->setDefaultStyleSheet(QStringLiteral("p.close_match { font-weight:bold; }"));
-    m_browser->viewport()->setBackgroundRole(QPalette::Background);
+    m_browser->viewport()->setBackgroundRole(QPalette::Window);
 
     QTimer::singleShot(0, this, &TMView::initLater);
     connect(m_catalog, QOverload<const QString &>::of(&Catalog::signalFileLoaded), this, &TMView::slotFileLoaded);
@@ -160,7 +160,7 @@ TMView::~TMView()
 #if QT_VERSION >= 0x050500
     int i = m_jobs.size();
     while (--i >= 0)
-        TM::threadPool()->cancel(m_jobs.at(i));
+        TM::threadPool()->tryTake(m_jobs.at(i));
 #endif
 }
 
@@ -219,7 +219,7 @@ void TMView::slotFileLoaded(const QString& filePath)
 #if QT_VERSION >= 0x050500
     int i = m_jobs.size();
     while (--i >= 0)
-        TM::threadPool()->cancel(m_jobs.at(i));
+        TM::threadPool()->tryTake(m_jobs.at(i));
 #endif
     m_jobs.clear();
 
@@ -351,7 +351,7 @@ void TMView::slotNewEntryDisplayed(const DocPosition& pos)
 #if QT_VERSION >= 0x050500
     int i = m_jobs.size();
     while (--i >= 0)
-        TM::threadPool()->cancel(m_currentSelectJob);
+        TM::threadPool()->tryTake(m_currentSelectJob);
 #endif
 
     //update DB
@@ -402,7 +402,7 @@ void TMView::slotSuggestionsCame(SelectJob* j)
     //check if this is an additional query, from secondary DBs
     if (job.m_dbName != projectID) {
         job.m_entries += m_entries;
-        std::sort(job.m_entries.begin(), job.m_entries.end(), qGreater<TMEntry>());
+        std::sort(job.m_entries.begin(), job.m_entries.end(), std::greater<TMEntry>());
         const int limit = qMin(Settings::suggCount(), job.m_entries.size());
         const int minScore = Settings::suggScore() * 100;
         int i = job.m_entries.size() - 1;
