@@ -2,6 +2,7 @@
   This file is part of KAider
 
   Copyright (C) 2007      by Nick Shaforostoff <shafff@ukr.net>
+                2018-2019 by Simon Depiets <sdepiets@gmail.com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -96,7 +97,6 @@ public slots:
      * @param codec e.g. UTF-8
      * @param rx RegExp that gives result in the first cap.
      *        e.g. "<div id=result_box dir=ltr>([^<]+)</div>"
-     * @param repeat whether func should be called again (frames)
      */
     void doDownloadAndFilter(QString url, QString codec, QString rx/*, int repeat*/);
 
